# Fedora 5, RHEL 5, and later versions includes SELinux policy module package
%if 0%{?fedora}%{?rhel} < 5
%global selinux_module 0
%global selinux_types %{nil}
%global selinux_variants %{nil}
%global selinux_buildreqs %{nil}
%else
%global selinux_module 1
%global selinux_types %(%{__awk} '/^#[[:space:]]*SELINUXTYPE=/,/^[^#]/ { if ($3 == "-") printf "%s ", $2 }' /etc/selinux/config 2>/dev/null)
%global selinux_variants %([ -z "%{selinux_types}" ] && echo mls strict targeted || echo %{selinux_types})
%global selinux_buildreqs checkpolicy, selinux-policy-devel, /usr/share/selinux/devel/policyhelp, hardlink
%endif

# Fedora 6 and later install to %%{_datadir}/php
%if 0%{?fedora} < 6
%global phpdir  %{_datadir}
%global hintdir ../
%else
%global phpdir  %{_datadir}/php
%global hintdir %{nil}
%endif

# Upstream has moved to using very unfriendly-named tarballs
%global gittag 5bc955b
%global tardir 4fe8ebe

Summary:        Web-based LDAP address book
Name:           contagged
Version:        0.7.2
Release:        2%{?dist}
License:        GPLv2+
Group:          Applications/Internet
URL:            http://www.cosmocode.de/en/opensource/contagged
Source0:        http://download.github.com/cosmocode-contagged-%{version}-0-g%{gittag}.tar.gz
Source1:        contagged-2.0.conf
Source2:        contagged-2.2.conf
Source3:        contagged-README.RPM
Source4:        contagged.fc
Source5:        contagged.if
Source6:        contagged.te
Source7:        contagged-README.SELinux
Patch0:         contagged-0.6.1-unbundle-smarty.patch
Patch1:         contagged-0.7.2-smarty3.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch:      noarch
Requires:       php-ldap, httpd
%if 0%{?fedora} < 6
# php-Smarty installed in %%{_datadir}
Requires:       php-Smarty
%else
# php-Smarty 2.6.16-1 and later install in %%{_datadir}/php
Requires:       php-Smarty >= 2.6.16-1
%endif
BuildRequires:  httpd symlinks %{selinux_buildreqs}
%if %{selinux_module}
# hack to avoid problems mixing new modules with older policy, e.g.
# http://www.redhat.com/archives/fedora-selinux-list/2006-May/msg00102.html
# Ideally this will be replaced by an ABI version requirement or something similar
%global selinux_policyver %(sed -e 's,.*selinux-policy-\\([^/]*\\)/.*,\\1,' /usr/share/selinux/devel/policyhelp 2>/dev/null)
%if "%{selinux_policyver}" != ""
Conflicts:      selinux-policy < %{selinux_policyver}
%endif
%endif

%global apachever %(/usr/sbin/httpd -v | %{__sed} -e '/version/ s|.*/\\([2-9]\\.[0-9]*\\).*|\\1|; q')

%description
ConTagged is a web-based address book for small companies written in PHP. It
provides access to a company-wide address book, as well as private address
books for each employee. All contact details are stored in the LDAP directory
and are available from all common e-mail clients.

Contacts can be grouped and looked up in infinite ways by assigning tags to
them.

ConTagged integrates perfectly into an existing infrastructure by using an
existing LDAP directory for authenticating the users.

%prep
%setup -q -n cosmocode-contagged-%{tardir}

# Unbundle Smarty
%patch0 -p1
%{__sed} -i -e 's,@@DIR_HINT@@,%{hintdir},' ajax.php inc/init.php
%if "%{apachever}" == "2.0"
%{__sed} -e 's,@@PHPDIR@@,%{phpdir},' %{SOURCE1} > contagged.conf
%else
%{__sed} -e 's,@@PHPDIR@@,%{phpdir},' %{SOURCE2} > contagged.conf
%endif

# Fix edit template email address form to work with Smarty 3.x
%patch1 -p0

# Prepare docs and SELinux policy module
%{__cp} -a %{SOURCE3} README.RPM
%{__mkdir} SELinux
%{__cp} -a %{SOURCE4} %{SOURCE5} %{SOURCE6} SELinux/
%{__cp} -a %{SOURCE7} SELinux/README.SELinux

# Don't want .htaccess files in package
%{__rm} contrib/.htaccess

%build
%if %{selinux_module}
cd SELinux
for selinuxvariant in %{selinux_variants}
do
    %{__make} NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile
    %{__mv} contagged.pp contagged.pp.${selinuxvariant}
    %{__make} NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile clean
done
cd -
%endif

%install
%{__rm} -rf %{buildroot}

# Create directories needed for installation
%{__install} -d %{buildroot}%{phpdir}/contagged
%{__install} -d %{buildroot}%{phpdir}/contagged/inc
%{__install} -d %{buildroot}%{phpdir}/Smarty/plugins
%{__install} -d %{buildroot}%{_localstatedir}/cache/contagged
%{__install} -d %{buildroot}%{_sysconfdir}/contagged
%{__install} -d %{buildroot}%{_sysconfdir}/httpd/conf.d

# Install application files
%{__cp} -a *.php pix scripts styles templates \
        %{buildroot}%{phpdir}/contagged/
%{__cp} -a inc/*.php inc/lang \
        %{buildroot}%{phpdir}/contagged/inc/

# Install custom Smarty plugins
%{__cp} -a inc/smarty/plugins/modifier.{csv,h,http,noteparser}.php \
        %{buildroot}%{phpdir}/Smarty/plugins

# Install SELinux policy modules
%if %{selinux_module}
cd SELinux
for selinuxvariant in %{selinux_variants}
do
    %{__install} -d %{buildroot}%{_datadir}/selinux/${selinuxvariant}
    %{__install} -p -m 644 contagged.pp.${selinuxvariant} \
           %{buildroot}%{_datadir}/selinux/${selinuxvariant}/contagged.pp
done
cd -
# Hardlink identical policy module packages together
/usr/sbin/hardlink -cv %{buildroot}%{_datadir}/selinux
%endif

# Replace config.php with a symlink to %%{_sysconfdir}/contagged/config.php
# Replace fields.php with a symlink to %%{_sysconfdir}/contagged/fields.php
# Install cache as a symlink to %%{_localstatedir}/cache/contagged
%{__mv} %{buildroot}%{phpdir}/contagged/inc/{config,fields}.php \
        %{buildroot}%{_sysconfdir}/contagged/
%{__ln_s} %{buildroot}%{_sysconfdir}/contagged/{config,fields}.php \
          %{buildroot}%{phpdir}/contagged/inc/
%{__ln_s} %{buildroot}%{_localstatedir}/cache/contagged \
          %{buildroot}%{phpdir}/contagged/cache
cd %{buildroot}%{phpdir}/contagged
/usr/bin/symlinks -csr .
cd -

# Install apache httpd configuration file
%{__install} -p -m 644 contagged.conf %{buildroot}%{_sysconfdir}/httpd/conf.d/

%clean
%{__rm} -rf %{buildroot}

%if %{selinux_module}
%post
# Install SELinux policy modules
if [ -x /usr/sbin/semodule ]; then
  for selinuxvariant in %{selinux_variants}
  do
    /usr/sbin/semodule -s ${selinuxvariant} -i \
      %{_datadir}/selinux/${selinuxvariant}/contagged.pp &> /dev/null || :
  done
fi
# Fix up non-standard directory context
[ -x /sbin/restorecon ] && /sbin/restorecon %{_localstatedir}/cache/contagged || :
%endif

%postun
# Clean up after package removal
if [ $1 -eq 0 ]; then
  # Clean out the cache
  %{__rm} -f %{_localstatedir}/cache/contagged/*.tpl.php
  /bin/rmdir %{_localstatedir}/cache/contagged &> /dev/null || :
%if %{selinux_module}
  # Remove SELinux policy modules
  if [ -x /usr/sbin/semodule ]; then
    for selinuxvariant in %{selinux_variants}
    do
      /usr/sbin/semodule -s ${selinuxvariant} -r contagged &> /dev/null || :
    done
  fi
  # Clean up any remaining file contexts (shouldn't be any really)
  [ -x /sbin/restorecon -a -d %{_localstatedir}/cache/contagged ] && \
    /sbin/restorecon -R %{_localstatedir}/cache/contagged &> /dev/null || :
%endif
fi

%files
%defattr(-,root,root,-)
%doc doc/COPYING doc/ldapab.schema doc/README doc/slapd.example doc/TODO VERSION
%doc README.RPM SELinux/README.SELinux contrib
%config(noreplace) %{_sysconfdir}/contagged/config.php
%config(noreplace) %{_sysconfdir}/contagged/fields.php
%config(noreplace) %{_sysconfdir}/httpd/conf.d/contagged.conf
%attr(0755,apache,apache) %{_localstatedir}/cache/contagged/
%{phpdir}/contagged/
%{phpdir}/Smarty/plugins/
%if %{selinux_module}
%{_datadir}/selinux/*/contagged.pp
%endif

%changelog
* Sun Dec  5 2010 Paul Howarth <paul@city-fan.org> 0.7.2-2
- Fix edit template email address form to work with Smarty 3.x

* Fri May 21 2010 Paul Howarth <paul@city-fan.org> 0.7.2-1
- Update to 0.7.2
  - Added country support (note that ldapab.schema is updated)
- Directory name doesn't even match tarball name now :-(

* Wed Oct 21 2009 Paul Howarth <paul@city-fan.org> 0.7.1-1
- Update to 0.7.1 (a few bugfixes and a Slovak translation)
  http://www.cosmocode.de/en/blog/gohr/2009-10/20-contagged-0.7.1-available
- Upstream tarball is now named after a git tag rather than the release
  number :-(

* Tue Jul 14 2009 Paul Howarth <paul@city-fan.org> 0.7.0-1
- Update to 0.7.0 (adds QR Code support and Vcard import fixes)
  http://www.cosmocode.de/en/blog/gohr/2009-07/14-contagged-now-with-qrcodes
- No upstream CHANGES file anymore
- Define RPM macros in global scope

* Tue Jun 16 2009 Paul Howarth <paul@city-fan.org> 0.6.5-2
- Add BR: /usr/share/selinux/devel/policyhelp because we need this actual file
  to grok the policy version number, and it can be found in either the
  selinux-policy, selinux-policy-devel, or selinux-policy-doc packages
  (depending on OS release)

* Fri Dec 12 2008 Paul Howarth <paul@city-fan.org> 0.6.5-1
- Update to 0.6.5

* Thu Dec  4 2008 Paul Howarth <paul@city-fan.org> 0.6.4-1
- Update to 0.6.4
- Try to determine supported SELinux policy types by reading /etc/selinux/config
- Upstream tarball now contains unversioned directory

* Fri Dec  7 2007 Paul Howarth <paul@city-fan.org> 0.6.3-1
- Update to 0.6.3
  (schema file ldapab.schema has additional attributes)
- Tarball now includes a versioned directory name
- CHANGES file missing from upstream tarball again
- Add contrib directory as %%doc
- Clarify license as GPL version 2 or later

* Mon Jul  9 2007 Paul Howarth <paul@city-fan.org> 0.6.2-1
- Update to 0.6.2

* Sat Jun 30 2007 Paul Howarth <paul@city-fan.org> 0.6.1-1
- Update to 0.6.1
- Rename README.Fedora for README.RPM
- Upstream tarball no longer includes versioned directory name
- Update unbundle-smarty patch
- Update %%prep and %%install for new file layout
- CHANGES now included in upstream tarball
- Config file entries.conf replaced by fields.php
- Remove provide for php-Smarty-noteparser, useless anywhere else

* Mon Jun 18 2007 Paul Howarth <paul@city-fan.org> 0.4-4
- Build selinux policy for RHEL5 builds too
- Add version/release to provides for php-Smarty-noteparser

* Thu Feb 22 2007 Paul Howarth <paul@city-fan.org> 0.4-3
- An FC6 update adds %%{_datadir}/php as a default include path, which is
  used by php-Smarty 2.6.16-1; tweak the unbundle-smarty patch to pick up
  Smarty from the include path rather than by directly referencing the files
  for distributions (FC6 onwards) where this will work

* Mon Feb 12 2007 Paul Howarth <paul@city-fan.org> 0.4-2
- Install to %%{_datadir}/php on FC7 onwards
- Rename README files in SRPM to try to avoid filename conflicts

* Tue Sep 12 2006 Paul Howarth <paul@city-fan.org> 0.4-1
- Update to 0.4
- Cleanup patches now incorporated upstream

* Tue Aug 29 2006 Paul Howarth <paul@city-fan.org> 0.3-11
- Buildreqs for FC5 now identical to buildreqs for FC6 onwards

* Fri Jul 28 2006 Paul Howarth <paul@city-fan.org> 0.3-10
- Build SELinux policy modules for all base policies and install them into the
  %%{_datadir}/selinux/POLICYNAME directory, hardlinking identical policy files
  together to avoid duplicate files
- Remove SELinux policy module packages silently if package is erased

* Mon Jul 24 2006 Paul Howarth <paul@city-fan.org> 0.3-9
- Refine buildreqs for SELinux modules (different for FC6 onwards)

* Wed Jun 21 2006 Paul Howarth <paul@city-fan.org> 0.3-8
- SELinux policy module cleaned up (requires httpd_cache_t)
- Conflict with selinux-policy older than the one the module is built with
- Removed commented-out sections of spec for different policy modules for
  different base policies, unlikely ever to be needed
- Add buildreq m4 if building SELinux policy

* Fri May 26 2006 Paul Howarth <paul@city-fan.org> 0.3-7
- More PHP cleanups
- BuildRequire selinux-policy >= 2.2.40 rather than
  selinux-policy-targeted >= 2.2.38
- Application available only from localhost by default
- Build separate policy modules for mls, strict, and targeted base policies

* Tue May 23 2006 Paul Howarth <paul@city-fan.org> 0.3-6
- Still more PHP cleanups (sigh)

* Mon May 22 2006 Paul Howarth <paul@city-fan.org> 0.3-5
- Provide php-Smarty-noteparser (custom plugin used by contagged)

* Thu May 18 2006 Paul Howarth <paul@city-fan.org> 0.3-4
- Make SELinux module support conditional, for FC < 5 support

* Wed May 17 2006 Paul Howarth <paul@city-fan.org> 0.3-3
- Use php-Smarty from Extras rather than bundled Smarty
  (thanks to Orion Poplawski)
- More PHP cleanups

* Tue May 16 2006 Paul Howarth <paul@city-fan.org> 0.3-2
- Don't put files under %%{_localstatedir}/www, put them under
  %%{_datadir}/contagged instead, with symlinks to files that
  need to be elsewhere
- Add buildreq symlinks
- Add README.SELinux
- Split main/policy packages don't work - see:
  http://www.redhat.com/archives/fedora-selinux-list/2006-May/msg00097.html
  So the SELinux policy is integrated into the main package and restorecon
  is used to fix up contexts in %%post

* Fri Apr 28 2006 Paul Howarth <paul@city-fan.org> 0.3-1
- Update to 0.3
- Patches included upstream, no longer needed
- Update contagged.conf to include Apache 2.2 LDAP directives
- Include CHANGES.txt from upstream but not in tarball
- Include selinux policy module in subpackage, required to be installed
  before main package to that files get installed with correct contexts

* Fri Mar  9 2006 Paul Howarth <paul@city-fan.org> 0.2-1
- Initial RPM build
